ElectrumSV Database
===================

    Licence: MIT License
    Maintainers: Roger Taylor, AustEcon
    Project Lead: Roger Taylor
    Homepage: https://electrumsv.io/


Overview
========

This is the database support library for ElectrumSV. This functionality has been extracted into
an independent package so that it can be used by other projects.
